#!/bin/sh

#===============================================================================
#Variables
#===============================================================================
RARC_VERSION="1.0.0.3"
RARC_JAR="rArc.jar"
RARC_SETUP_JAR="rArcSetup.jar"
RARC_SCRIPT="rArc.sh"
RARC_SETUP_SCRIPT="rArcSetup.sh"
RARC_UPDATE_SCRIPT="rArcUpdate.sh"
RARC_MENU_ITEM="rArc.desktop"
RARC_STARTUP_FILE="rArc.desktop"
RARC_UPDATE_STARTUP_FILE="rArcUpdate.desktop"
JAVA_REQUIRED_VERSION="1.6"
REQUIRED_FREE_SPACE="0.1"
EXECUTE_FOLDER=`pwd`

#===================================================================
create_menu_item()
#===================================================================
{

FOLDER_MENU="$HOME/.local/share/applications"

[ ! -d $FOLDER_MENU ] && mkdir -p $FOLDER_MENU

FILE_CREATE="$FOLDER_MENU/$RARC_MENU_ITEM"

echo "#!/usr/bin/env xdg-open" > $FILE_CREATE
echo "[Desktop Entry]" >> $FILE_CREATE
echo "Encoding=UTF-8" >> $FILE_CREATE
echo "Version=1.0" >> $FILE_CREATE
echo "Type=Application" >> $FILE_CREATE
echo "Terminal=false" >> $FILE_CREATE
echo "Name[en_US]=rARC" >> $FILE_CREATE
echo "Exec=$EXECUTE_FOLDER/./$RARC_SCRIPT 1" >> $FILE_CREATE
echo "Comment[en_US]=Replication of ARC" >> $FILE_CREATE
echo "Name=rARC" >> $FILE_CREATE
echo "Comment=Replication of ARC" >> $FILE_CREATE
echo "Categories=Network;" >> $FILE_CREATE
echo "Icon=$EXECUTE_FOLDER/icon/logo.png" >> $FILE_CREATE

if [ -f $FILE_CREATE ]; then
	return 1
fi

return 0
}

#===================================================================
detected_java()
#===================================================================
{

java -version 2> java_temp.tmp

JAVA_VERSION=`awk '/java version/ {print substr($3, 2, 3); }' java_temp.tmp`

rm java_temp.tmp

RESULT=$(echo "$JAVA_VERSION >= $JAVA_REQUIRED_VERSION" | bc)
if [ $RESULT -eq 1 ]; then
	return 1
else
	return 0
fi

}

#===================================================================
exists_enough_freespace()
#===================================================================
{

FREE_SPACE_AVAILABLE=`df -h $EXECUTE_FOLDER | awk '/.*G/ {print $4}' | sed 's/G//g'`

RESULT=$(echo "$FREE_SPACE_AVAILABLE > $REQUIRED_FREE_SPACE" | bc)
if [ $RESULT -eq 1 ]; then
	return 1
else
	return 0
fi

}


#===================================================================
create_startup()
#===================================================================
{

FOLDER_STARTUP="$HOME/.config/autostart/"

[ ! -d $FOLDER_STARTUP ] && mkdir -p $FOLDER_STARTUP

FILE_CREATE="$FOLDER_STARTUP/$RARC_STARTUP_FILE"
echo "[Desktop Entry]" > $FILE_CREATE
echo "Type=Application" >> $FILE_CREATE
echo "Name=rArc" >> $FILE_CREATE
echo "Exec=$EXECUTE_FOLDER/./$RARC_SCRIPT 30" >> $FILE_CREATE
echo "Icon=system-run" >> $FILE_CREATE
echo "Comment=" >> $FILE_CREATE

if [ ! -f $FILE_CREATE ]; then
	return 0
fi


FILE_CREATE="$FOLDER_STARTUP/$RARC_UPDATE_STARTUP_FILE"
echo "[Desktop Entry]" > $FILE_CREATE
echo "Type=Application" >> $FILE_CREATE
echo "Name=rArcUpdate" >> $FILE_CREATE
echo "Exec=$EXECUTE_FOLDER/./$RARC_UPDATE_SCRIPT" >> $FILE_CREATE
echo "Icon=system-run" >> $FILE_CREATE
echo "Comment=" >> $FILE_CREATE

if [ ! -f $FILE_CREATE ]; then
	return 0
fi

return 1
}

#===================================================================
create_scripts()
#===================================================================
{

echo "#!/bin/sh" > rArcSetup.tmp
echo "cd $EXECUTE_FOLDER" >> rArcSetup.tmp
cat rArcSetup.sh >> rArcSetup.tmp
mv rArcSetup.tmp rArcSetup.sh
chmod +x rArcSetup.sh

if [ ! -f "rArcSetup.sh" ]; then
	return 0
fi


echo "#!/bin/sh" > rArc.tmp
echo "cd $EXECUTE_FOLDER" >> rArc.tmp
cat rArc.sh >> rArc.tmp
mv rArc.tmp rArc.sh
chmod +x rArc.sh

if [ ! -f "rArc.sh" ]; then
	return 0
fi


echo "#!/bin/sh" > rArcUpdate.tmp
echo "cd $EXECUTE_FOLDER" >> rArcUpdate.tmp
echo "" >> rArcUpdate.tmp
echo "EXECUTE_FOLDER=$EXECUTE_FOLDER" >> rArcUpdate.tmp
cat rArcUpdate.sh >> rArcUpdate.tmp
mv rArcUpdate.tmp rArcUpdate.sh
chmod +x rArcUpdate.sh

if [ ! -f "rArcUpdate.sh" ]; then
	return 0
fi

return 1

}


#===================================================================
select_language()
#Function:
#Return:
#===================================================================
{

while : ;
do
echo "Select language used on rARC interface:"
echo "English [EN]" 
echo "Português [pt]"
echo -n "Select: "


read RESULT

LENGTH=`echo ${#RESULT}`

if [ $LENGTH -eq 0 ]; then
	LANGUAGE="enGB"
	break
else
	if [ $RESULT = "en" -o $RESULT = "EN" ]; then
		LANGUAGE="enGB"
		break
	elif [ $RESULT = "pt" -o $RESULT = "PT" ]; then
		LANGUAGE="ptPT"
		break
	else
		echo "Wrong option"
		echo ""
	fi
fi
done

}

#===================================================================
confirm_folder()
#===================================================================
{

while : ;
do
echo "rARC will be installed in the current directory [$EXECUTE_FOLDER]"
echo "Do you want to continue?[Y/n]"
echo -n "Select: "
read RESULT

LENGTH=`echo ${#RESULT}`

if [ $LENGTH -eq 0 ]; then
	return 1
else
	if [ $RESULT = "Y" -o $RESULT = "y" ]; then
		echo ""
		return 1
	elif [ $RESULT = "n" -o $RESULT = "N" ]; then
		return 0
	else
		echo "Wrong option"
		echo ""
	fi
fi

done

}


#===============================================================================
launch_rArcSetup_rArcUpdate()
#===============================================================================
{

cd $EXECUTE_FOLDER

./rArcSetup.sh &
./rArcUpdate.sh &

}

#===============================================================================
are_you_root()
#===============================================================================
{

if [ $(id -u) = "0" ]; then
	return 0
else
	return 1	
fi

}

#===============================================================================
confirm_requirements()
#===============================================================================
{

OUTPUT_WHEREIS_NO_WGET="wget:"
GET_OUTPUT_WHEREIS_WGET=`whereis wget`

if [ ${#OUTPUT_WHEREIS_NO_WGET} -eq ${#GET_OUTPUT_WHEREIS_WGET} ]; then
	echo "This computer does not have wget program installed."
	return 0
else
	return 1
fi

}


#===============================================================================
#MAIN
#===============================================================================

confirm_requirements
if [ $? -eq 0 ]; then
	echo ""
	echo "Read the README file to confirm that your computer fulfils the requirements."
	exit
fi

are_you_root
if [ $? -eq 0 ]; then
	echo ""
	echo "You have to install rARC as user."
	exit
fi

confirm_folder
if [ $? -eq 0 ]; then
	echo ""
	echo "You decided to cancel the installation"
	exit
fi

select_language

detected_java
if [ $? -eq 0 ]; then
	echo ""
	echo "rARC runs on Java Sun JRE (>=1.6) or OpenJDK (IcedTea6 1.6)."
	echo "Use this shell command: java -version, to verify your java version."
	exit
fi

create_scripts
if [ $? -eq 0 ]; then
	echo ""
	echo "Verify the permissions of the folder where you are installing rARC."
	exit
fi

create_startup
if [ $? -eq 0 ]; then
	echo ""
	echo "Verify the permissions of the folder where you are installing rARC."
	exit
fi

create_menu_item
if [ $? -eq 0 ]; then
	#TODO
	continue
fi

echo "The installation is completed...click [Enter] to launch a setup application setup application."

read RESULT

launch_rArcSetup_rArcUpdate

exit
